@@ -27,6 +27,7 @@ import requests
 import logging
 import http.client
 from cakework import auth
+import os
 
 logging.basicConfig(level=logging.INFO)
 
@@ -68,14 +69,15 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
             response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "result": json.dumps(res)}, headers=headers)
             # TODO check the response
             response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "SUCCEEDED"}, headers=headers)
-
         except Exception as e:
             logging.exception("Error occurred while running task", exc_info=True)
             # logging.info(e)
             response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "FAILED"})
             # TODO: handle case if updating the status in the db failed; then user may keep polling forever
             return cakework_pb2.Reply(result=None)
-
+        finally:
+            print("Finally; os.exiting")
+            os._exit(1)
         # Q: who are we returning to here? instead of returning, we can just write this to the database. or emit a message and have the poller be in charge of writing to db
         return cakework_pb2.Reply(result=json.dumps(res))
 
@@ -86,6 +88,8 @@ def serve():
     server.add_insecure_port('[::]:' + port)
     server.start()
     logging.info("Server started, listening on " + port)
+    # TODO delete!!
+    sys.exit("Exiting as soon as spun up")
     server.wait_for_termination()
 
 if __name__ == '__main__':
