@@ -11,7 +11,6 @@ import logging
 from cakework import exceptions
 from urllib3.exceptions import NewConnectionError
 import os
-from cakework import auth
 
 # TODO: need to re-enable TLS for the handlers in the fly.toml file. Try these settings: https://community.fly.io/t/urgent-grpc-server-unreachable-via-grpcurl/2694/12 for alpn
 # TODO figure out how to configure the settings for fly.toml for grpc!
@@ -36,39 +35,33 @@ class Client:
 
             # based on the particular user id, how do we fetch user credentials and get a token on behalf of the user?
             # need SOME sort of token first
-            token = auth.get_token("LtM7DMVVmENYKIL8UYIvcUqmQxxwru5B", "CJ2HtEMSGMWVyxxlHfuluPLQ4-ZDrcOTIF_DDUmabkog24DuHLV8ElaL08gk8wVG", "get:user_from_client_token get:status get:result submit:task")
-            self.headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
-            response = requests.get(f"{self.frontend_url}/get-user-from-client-token", json={"token": client_token}, headers=self.headers)      # Q: should this take app?        
+            self.headers = {'content-type': 'application/json', 'X-Api-Key': client_token}
+            response = requests.get(f"{self.frontend_url}/client/get-user-from-client-token", json={"token": client_token}, headers=self.headers)      # Q: should this take app?        
                
-            # if dont' get a avalid user
+            # if dont' get a a valid user
             # TODO raise exception
                        
             # TODO: handle error for if can't get a user from the client token. technically
             # we should be getting a JWT token instead first
             response.raise_for_status() # TODO delete this?
-            # TODO: handle http error, or request id not found error
-        except requests.exceptions.HTTPError as errh:
-            logging.exception("Http error while connecting to Cakework frontend", exc_info=True)
-            raise exceptions.CakeworkError("Http error while connecting to Cakework frontend")
-        except requests.exceptions.Timeout as errt:
-            logging.exception("Timed out connecting to Cakework frontend", exc_info=True)
-            raise exceptions.CakeworkError("Timed out connecting to Cakework frontend")
+            # TODO: handle http error, or request id not foundain. error
+        except requests.exceptions.HTTPError as err:
+            raise exceptions.CakeworkError("Http error while connecting to Cakework frontend") from err
+        except requests.exceptions.Timeout as err:
+            raise exceptions.CakeworkError("Timed out connecting to Cakework frontend") from err
         except requests.exceptions.RequestException as err:
-            logging.exception("Request exception connecting to Cakework frontend", exc_info=True)
-            raise exceptions.CakeworkError("Request exception connecting to Cakework frontend")
-        except (ConnectionRefusedError, ConnectionResetError) as e:
-            logging.exception("Failed to connect to Cakework frontend service", exc_info=True)
-            raise exceptions.CakeworkError("Failed to connect to Cakework frontend service")
-        except Exception as e:
+            raise exceptions.CakeworkError("Request exception connecting to Cakework frontend") from err
+        except (ConnectionRefusedError, ConnectionResetError) as err:
+            raise exceptions.CakeworkError("Failed to connect to Cakework frontend service") from err
+        except Exception as err:
             # TODO catch and raise specific errors? 
-            logging.exception("Error happened while initializing client", exc_info=True)
-            raise exceptions.CakeworkError("Something unexpected happened")
+            raise exceptions.CakeworkError("Error happened while initializing Cakework client") from err
         if response is not None:
             if response.status_code == 200:
                 response_json = response.json()
                 self.user_id = response_json["id"] # Q: how to return None if process is still executing? instead of empty string
-                self.headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
             else:
+                # TODO add logging to figure out what happened
                 raise exceptions.CakeworkError("Error happened while trying to get the user from the client token")
         else:
             raise exceptions.CakeworkError("Error happened while trying to get the user from the client token")
@@ -80,25 +73,20 @@ class Client:
         try:
             # Q: status 200 vs 201??? what's the diff?
             # TODO strip app from everywhere
-            response = requests.get(f"{self.frontend_url}/get-status", json={"userId": self.user_id, "app": self.project, "requestId": request_id}, headers=self.headers)                
-            response.raise_for_status() # TODO delete this?
+            response = requests.get(f"{self.frontend_url}/client/get-status", json={"userId": self.user_id, "app": self.project, "requestId": request_id}, headers=self.headers)                
+            response.raise_for_status()
             # TODO: handle http error, or request id not found error
-        except requests.exceptions.HTTPError as errh:
-            logging.exception("Http error while connecting to Cakework frontend", exc_info=True)
-            raise exceptions.CakeworkError("Http error while connecting to Cakework frontend")
-        except requests.exceptions.Timeout as errt:
-            logging.exception("Timed out connecting to Cakework frontend", exc_info=True)
-            raise exceptions.CakeworkError("Timed out connecting to Cakework frontend")
+        except requests.exceptions.HTTPError as err:
+            raise exceptions.CakeworkError("Http error while connecting to Cakework frontend") from err
+        except requests.exceptions.Timeout as err:
+            raise exceptions.CakeworkError("Timed out connecting to Cakework frontend") from err
         except requests.exceptions.RequestException as err:
-            logging.exception("Request exception connecting Cakework frontend", exc_info=True)
-            raise exceptions.CakeworkError("Request exception connecting Cakework frontend")
-        except (ConnectionRefusedError, ConnectionResetError) as e:
-            logging.exception("Failed to connect to Cakework frontend service", exc_info=True)
-            raise exceptions.CakeworkError("Failed to connect to Cakework frontend service")
-        except Exception as e:
+            raise exceptions.CakeworkError("Request exception connecting Cakework frontend") from err
+        except (ConnectionRefusedError, ConnectionResetError) as err:
+            raise exceptions.CakeworkError("Failed to connect to Cakework frontend service") from err
+        except Exception as err:
             # TODO catch and raise specific errors? 
-            logging.exception("Error happened while getting status", exc_info=True)
-            raise exceptions.CakeworkError("Something unexpected happened")
+            raise exceptions.CakeworkError("Error happened while getting status") from err
         if response is not None:
             if response.status_code == 200:
                 response_json = response.json()
@@ -116,24 +104,19 @@ class Client:
         response = None
         try:
             # Q: status 200 vs 201??? what's the diff?
-            response = requests.get(f"{self.frontend_url}/get-result", json={"userId": self.user_id, "app": self.project, "requestId": request_id}, headers=self.headers)                
+            response = requests.get(f"{self.frontend_url}/client/get-result", json={"userId": self.user_id, "app": self.project, "requestId": request_id}, headers=self.headers)                
             response.raise_for_status() # TODO delete this?
             # TODO: handle http error, or request id not found error
         except requests.exceptions.HTTPError as errh:
-            logging.exception("Http error while connecting to Cakework frontend", exc_info=True)
             raise exceptions.CakeworkError("Http error while connecting to Cakework frontend")
         except requests.exceptions.Timeout as errt:
-            logging.exception("Timed out connecting to Cakework frontend", exc_info=True)
             raise exceptions.CakeworkError("Timed out connecting to Cakework frontend")
         except requests.exceptions.RequestException as err:
-            logging.exception("Request exception connecting Cakework frontend", exc_info=True)
             raise exceptions.CakeworkError("Request exception connecting Cakework frontend")
         except (ConnectionRefusedError, ConnectionResetError) as e:
-            logging.exception("Failed to connect to Cakework frontend service", exc_info=True)
             raise exceptions.CakeworkError("Failed to connect to Cakework frontend service")
         except Exception as e:
             # TODO catch and raise specific errors? 
-            logging.exception("Error happened while getting status", exc_info=True)
             raise exceptions.CakeworkError("Something unexpected happened")
         if response is not None:
             if response.status_code == 200:
@@ -151,12 +134,9 @@ class Client:
         def method(*args):
             sanitized_name = name.lower()
             sanitized_name = name.replace('_', '-')          
-            response = requests.post(f"{self.frontend_url}/submit-task", json={"userId": self.user_id, "app": self.project, "task": sanitized_name, "parameters": json.dumps(args)}, headers=self.headers)
+            response = requests.post(f"{self.frontend_url}/client/submit-task", json={"userId": self.user_id, "app": self.project, "task": sanitized_name, "parameters": json.dumps(args)}, headers=self.headers)
             response_json = response.json()
             request_id = response_json["requestId"] # this may be null?
             return request_id
 
-        return method
-    
-# if __name__ == '__main__':
-#     run() 
\ No newline at end of file
+        return method
\ No newline at end of file
